@@ -64,7 +64,7 @@ sampleRegular <- function( x, size, ext=NULL, cells=FALSE, asRaster=FALSE) {
 	
 
 	driver <- .driver(x, FALSE)
-	if (driver=='gdal' & !rotated) {
+	if (driver=='gdal' & !rotated & !cells) {
 	
 		offs <- c(firstrow,firstcol)-1
 		reg <- c(nrow(rcut), ncol(rcut))-1
@@ -79,7 +79,11 @@ sampleRegular <- function( x, size, ext=NULL, cells=FALSE, asRaster=FALSE) {
 		if (x@data@gain != 1 | x@data@offset != 0) {
 			v <- v * x@data@gain + x@data@offset
 		}
-	
+		if (x@file@nodatavalue < 0) {
+			v[v <= x@file@nodatavalue] <- NA
+		} else {
+			v[v == x@file@nodatavalue] <- NA
+		}
 	
 		if (asRaster) {
 			if (is.null(ext))  {
@@ -96,8 +100,7 @@ sampleRegular <- function( x, size, ext=NULL, cells=FALSE, asRaster=FALSE) {
 				return( setValues(outras, as.vector(v)))
 			}
 		} else {
-		
-			return(v@data)
+			return(v)
 		}
 	}
 
